Module opus_decoder

Module opus_decoder 

Low-level decoder API mirroring libopus.

Structs

OpusDecoder
Top-level Opus decoder wrapper.
ParsedPacketMetadata
Packet metadata extracted from the top-level decoder front-end.

Enums

OpusDecodeError
Errors surfaced by the top-level decoder front-end.
OpusDecoderCtlError
Errors that can be emitted by opus_decoder_ctl.
OpusDecoderCtlRequest
Strongly-typed replacement for the decoder-side varargs CTL dispatcher.
OpusDecoderInitError
Error codes reported by the top-level decoder helpers.

Functions

opus_decode
Wrapper for decoding into 16-bit PCM, mirroring opus_decode.
opus_decode24
Wrapper for decoding into 24-bit PCM stored in i32, mirroring opus_decode24.
opus_decode_float
Wrapper for decoding into floating-point PCM, mirroring opus_decode_float.
opus_decode_native
Mirrors opus_decode_native while delegating frame decode to the embedded closure.
opus_decoder_create
Mirrors opus_decoder_create by allocating and initialising a decoder.
opus_decoder_ctl
Applies a control request to the provided decoder state.
opus_decoder_get_nb_samples
Mirrors opus_decoder_get_nb_samples by delegating to the packet helper with the decoder’s Fs.
opus_decoder_get_size
Returns the number of bytes required to allocate an Opus decoder for channels.